@@ -105,6 +105,8 @@ icc <- function(x, ...) {
       icc_[[length(icc_) + 1]] <- icc.lme4(p_)
     }
     names(icc_) <- NULL
+    # add class attribute
+    # class(icc_) <- c(class(icc_), "icc.lme4.list")
   }
   return(icc_)
 }
@@ -192,7 +194,7 @@ icc.lme4 <- function(fit) {
     attr(ri.icc, "family") <- stats::family(fit)$family
     attr(ri.icc, "link") <- stats::family(fit)$link
     attr(ri.icc, "formula") <- stats::formula(fit)
-    attr(ri.icc, "model") <- ifelse(any(class(fit) == "glmerMod"), "Generalized inear mixed model", "Linear mixed model")
+    attr(ri.icc, "model") <- ifelse(any(class(fit) == "glmerMod"), "Generalized linear mixed model", "Linear mixed model")
     attr(ri.icc, "tau.00") <- tau.00
     attr(ri.icc, "tau.01") <- tau.01
     attr(ri.icc, "rho.01") <- rho.01
@@ -299,4 +301,4 @@ get_re_var <- function(x, comp = c("tau.00", "tau.01", "tau.11", "rho.01", "sigm
 
   # return results
   return(attr(x, comp, exact = TRUE))
-}
\ No newline at end of file
+}
