@@ -70,11 +70,6 @@ overdisp.default <- function(x, trafo) {
 
 
 overdisp.lme4 <- function(x) {
-  # check if suggested package is available
-  if (!requireNamespace("lme4", quietly = TRUE)) {
-    stop("Package `lme4` needed for this function to work. Please install it.", call. = FALSE)
-  }
-
   # check object class
   if (any(class(x) == "glmerMod")) {
     rdf <- stats::df.residual(x)
